function val = g2(problem,x1,x2)
% This file is part of the OPTPDE problem collection
%                 http://www.optpde.net
% It is provided as is, without any warranty, under the 
%
% Creative Commons Attribution-NonCommercial ShareAlike 4.0 International
%
%         http://creativecommons.org/licenses/by-nc-sa/4.0/
%
% Please give proper credits when using this file by referencing the 
% collection. For this purpose detailed bibliography data is 
% available at the collections website 
%                  
%                 http://www.optpde.net
%
% This file contains data for the benchmark problem 
%                      ccbnd1
% from  2022-04-01 



% remember the size of the input and resize it
[m,n] = size(x1);
x1 = x1(:)';
x2 = x2(:)';

% convert input to polar coordinates
[phi,r] = cart2pol(x1,x2);
phi(phi<0) = phi(phi<0) + 2*pi;

% evaluate the desired state yd
tmpval = yd(problem,r,phi);

% and restrict it to [-1/2, 1/2]
tmpval = max(tmpval,-0.5);
tmpval = min(tmpval, 0.5);

% set the value to nan where (x1,x2) does not belong to the boundary
ix1 = find((x2 == 0) & (0 <= x1) & (x1 <= 1));
ix2 = find((x1 == 1) & (0 <= x2) & (x2 <= 1));
ix3 = find((x2 == 1) & (-1 <= x1) & (x1 <= 1));
ix4 = find((x1 == -1) & (-1 <= x2) & (x2 <= 1));
ix5 = find((x2 == -1) & (-1 <= x1) & (x1 <= 1));
ix6 = find((x1 == 1) & (-1 <= x2) & (x2 <= 0));
ix7 = find(abs(phi-problem.omega) <= pi/180);
ix = [ix1,ix2,ix3,ix4,ix5,ix6,ix7];

% prepare the output
val = nan(size(x1));
val(ix) = tmpval(ix);

% reshape the output
val = reshape(val,m,n);

